# Game modes directory

Place game modes you want to use with piqueserver in here and set the
`game_mode` in config to the name of the module you wish to use.

Eg. if you put a game_mode file called `mygame.py` in this directory, you can
set the `game_mode` option in `config.toml` to `"mygame"`.
